.. _abrechnung-dev-api:

******************
API
******************

.. only:: builder_html

  Download the json formatted openapi spec :download:`here <../_build/openapi.json>`.

.. openapi:: ../_build/openapi.json
  :group:
